# Python

!!! warning 
    Experimaestro is compatible with Python 3 only.

You need a working `python3` interpreter on your system along with `pip3`.

To install required python's modules type:

```sh
pip3 install experimaestro
```

